pub struct RenderSettings {
pub x_scale: f32,
pub y_scale: f32,
pub width: Option<u16>,
pub height: Option<u16>,
pub bg_color: AlphaColor<Srgb>,
}Expand description
Settings to apply during rendering.
Fields
x_scale: f32How much the contents should be scaled into the x direction.
y_scale: f32How much the contents should be scaled into the y direction.
width: Option<u16>The width of the viewport. If this is set to None, the width will be chosen
automatically based on the scale factor and the dimensions of the PDF.
height: Option<u16>The height of the viewport. If this is set to None, the height will be chosen
automatically based on the scale factor and the dimensions of the PDF.
bg_color: AlphaColor<Srgb>The background color. Determines the color of the base rectangle during rendering to a pixmap.